library(tidyverse)
library(terra)
library(rnaturalearth)
library(sf)

# Define Study extent ####
sa_polygon = rnaturalearth::ne_countries(scale = 10, returnclass = "sf") %>% 
  dplyr::filter(continent == "South America") %>% 
  sf::st_union() %>% 
  sf::st_crop(xmin = -82, ymin = -56, xmax = -34, ymax = 13)

save(sa_polygon, file = "data/r_objects/sa_polygon.RData")

# CHELSA bioclim target variables ####
chelsa_urls = paste0("https://os.zhdk.cloud.switch.ch/chelsav2/GLOBAL/climatologies/1981-2010/bio/CHELSA_bio", 1:19,"_1981-2010_V.2.1.tif")
 
chelsa = terra::rast(chelsa_urls) %>% 
  crop(sa_polygon)
set.names(chelsa, paste0("bio", 1:19))
terra::writeRaster(chelsa, filename = file.path("data", "geospatial", "raster", basename(chelsa_urls)), overwrite = T)